@@ -17,6 +17,7 @@
 from pm4py.util import xes_constants as xes
 from pm4py.util import exec_utils
 from pm4py.algo.enhancement.sna.parameters import Parameters
+from pm4py.util import variants_util
 
 
 def apply(log, parameters=None):
@@ -50,19 +51,21 @@ def apply(log, parameters=None):
     variants_occ = {x["variant"]: x["case:concept:name"] for x in
                     case_statistics.get_variant_statistics(log, parameters=parameters_variants)}
     variants_resources = list(variants_occ.keys())
-    resources = [x.split(",") for x in variants_resources]
+    resources = [variants_util.get_activities_from_variant(y) for y in variants_resources]
+
     flat_list = sorted(list(set([item for sublist in resources for item in sublist])))
 
     metric_matrix = numpy.zeros((len(flat_list), len(flat_list)))
 
-    for rv in resources:
+    for idx, rv in enumerate(resources):
+        rvj = variants_resources[idx]
         ord_res_list = sorted(list(set(rv)))
 
         for i in range(len(ord_res_list) - 1):
             res_i = flat_list.index(ord_res_list[i])
             for j in range(i + 1, len(ord_res_list)):
                 res_j = flat_list.index(ord_res_list[j])
-                metric_matrix[res_i, res_j] += float(variants_occ[",".join(rv)]) / float(len(log))
-                metric_matrix[res_j, res_i] += float(variants_occ[",".join(rv)]) / float(len(log))
+                metric_matrix[res_i, res_j] += float(variants_occ[rvj]) / float(len(log))
+                metric_matrix[res_j, res_i] += float(variants_occ[rvj]) / float(len(log))
 
     return [metric_matrix, flat_list, False]
