@@ -1,12 +1,45 @@
-import pm4py
-from pm4py.algo.conformance.tokenreplay import algorithm as executor
-from pm4py.algo.conformance.tokenreplay.versions import token_replay
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
+from pm4py.algo.conformance.tokenreplay.variants import token_replay
 from pm4py.statistics.variants.log import get as variants_module
-from pm4py.objects.petri.petrinet import PetriNet
+from pm4py.objects.petri_net.obj import PetriNet
 from pm4py.objects.random_variables.random_variable import RandomVariable
-from pm4py.objects.petri import performance_map
-from pm4py.simulation.montecarlo.parameters import Parameters
+from pm4py.objects.petri_net.utils import performance_map
 from pm4py.util import exec_utils, constants, xes_constants
+from pm4py.algo.conformance.tokenreplay import algorithm as executor
+
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
+    TOKEN_REPLAY_VARIANT = "token_replay_variant"
+    PARAM_NUM_SIMULATIONS = "num_simulations"
+    PARAM_FORCE_DISTRIBUTION = "force_distribution"
+    PARAM_ENABLE_DIAGNOSTICS = "enable_diagnostics"
+    PARAM_DIAGN_INTERVAL = "diagn_interval"
+    PARAM_CASE_ARRIVAL_RATIO = "case_arrival_ratio"
+    PARAM_PROVIDED_SMAP = "provided_stochastic_map"
+    PARAM_MAP_RESOURCES_PER_PLACE = "map_resources_per_place"
+    PARAM_DEFAULT_NUM_RESOURCES_PER_PLACE = "default_num_resources_per_place"
+    PARAM_SMALL_SCALE_FACTOR = "small_scale_factor"
+    PARAM_MAX_THREAD_EXECUTION_TIME = "max_thread_exec_time"
 
 
 def get_map_from_log_and_net(log, net, initial_marking, final_marking, force_distribution=None, parameters=None):
@@ -27,8 +60,8 @@ def get_map_from_log_and_net(log, net, initial_marking, final_marking, force_dis
         If provided, distribution to force usage (e.g. EXPONENTIAL)
     parameters
         Parameters of the algorithm, including:
-            PARAM_ACTIVITY_KEY -> activity name
-            PARAM_TIMESTAMP_KEY -> timestamp key
+            Parameters.ACTIVITY_KEY -> activity name
+            Parameters.TIMESTAMP_KEY -> timestamp key
 
     Returns
     -----------
@@ -41,9 +74,10 @@ def get_map_from_log_and_net(log, net, initial_marking, final_marking, force_dis
         parameters = {}
 
     token_replay_variant = exec_utils.get_param_value(Parameters.TOKEN_REPLAY_VARIANT, parameters,
-                                                      Parameters.DEFAULT_TOKEN_REPLAY_VARIANT.value)
+                                                      executor.Variants.TOKEN_REPLAY)
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_constants.DEFAULT_NAME_KEY)
-    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_constants.DEFAULT_TIMESTAMP_KEY)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters,
+                                               xes_constants.DEFAULT_TIMESTAMP_KEY)
 
     parameters_variants = {constants.PARAMETER_CONSTANT_ACTIVITY_KEY: activity_key}
     variants_idx = variants_module.get_variants_from_log_trace_idx(log, parameters=parameters_variants)
@@ -53,7 +87,7 @@ def get_map_from_log_and_net(log, net, initial_marking, final_marking, force_dis
 
     # do the replay
     aligned_traces = executor.apply(log, net, initial_marking, final_marking, variant=token_replay_variant,
-                                    parameters=parameters_tr)
+                                        parameters=parameters_tr)
 
     element_statistics = performance_map.single_element_statistics(log, net, initial_marking,
                                                                    aligned_traces, variants_idx,
